@@ -1,8 +1,8 @@
 /*
  *      encodings.h - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2005-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2006-2009 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2005-2011 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2006-2011 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: encodings.h 3446 2009-01-04 18:30:42Z eht16 $
+ *  $Id: encodings.h 5606 2011-03-18 15:57:02Z colombanw $
  */
 
 
@@ -63,9 +63,9 @@ typedef struct
 	/** Internally used member for grouping */
 	GeanyEncodingGroup   group;
 	/** String representation of the encoding, e.g. "ISO-8859-3" */
-	gchar				*charset;
+	const gchar			*charset;
 	/** Translatable and descriptive name of the encoding, e.g. "South European" */
-	gchar				*name;
+	const gchar			*name;
 } GeanyEncoding;
 
 
@@ -90,6 +90,8 @@ gchar *encodings_convert_to_utf8_from_charset(const gchar *buffer, gsize size,
 
 gboolean encodings_is_unicode_charset(const gchar *string);
 
+gboolean encodings_convert_to_utf8_auto(gchar **buf, gsize *size, const gchar *forced_enc,
+		gchar **used_encoding, gboolean *has_bom, gboolean *partial);
 
 /*
  * The original versions of the following tables are taken from profterm
@@ -174,6 +176,7 @@ typedef enum
 	GEANY_ENCODING_WINDOWS_1258,
 
 	GEANY_ENCODING_NONE,
+	GEANY_ENCODING_CP_932,
 
 	GEANY_ENCODINGS_MAX
 } GeanyEncodingIndex;
